#include "timer.h"

#include <HardwareSerial.h>

Timer::Timer(const unsigned long duration, const bool autoRestart): currentTime(0), running(false)
{
    this->autoRestart = autoRestart;
    this->duration = duration;
    this->endTime = duration;
}

void Timer::start()
{
    this->running = true;
}

bool Timer::update(const unsigned long delta)
{
    // Serial.print("Timer ");
    if (!running)
    {
    // Serial.print(" not running...");
        return false;
    }
    bool timedOut = false;
    this->currentTime += delta;
    // Serial.print(" target : " + String(this->currentTime) + "/" + String(this->endTime));
    if (currentTime > this->endTime)
    {
        timedOut = true;
    }
    if (timedOut && this->autoRestart)
    {
        this->endTime += this->duration;
    }
    if (timedOut && !this->autoRestart)
    {
        running = false;
    }
    return timedOut;
}

bool Timer::isRunning() const
{
    return this->running;
}

unsigned long Timer::getDuration() const
{
    return this->duration;
}

unsigned long Timer::getCurrentTime() const
{
    return this->currentTime;
}
